## dbt-adapters 1.16.0 - June 04, 2025

### Features

- Add constant defining name of logical catalog in model config ([#1134](https://github.com/dbt-labs/dbt-adapters/issues/1134))

### Fixes

- Fix casing issue in snapshot target validation. ([#1101](https://github.com/dbt-labs/dbt-adapters/issues/1101))

### Under the Hood

- populate file_format from top level integration config field ([#1129](https://github.com/dbt-labs/dbt-adapters/issues/1129))
